@@ -6,3 +6,7 @@ ggname <- function(prefix, grob) {
   grob$name <- grid::grobName(grob, prefix)
   grob
 }
+
+has_groups <- function(data) {
+  data$group[1L] != -1L
+}
